@@ -638,6 +638,62 @@ class AtlasProjection:
 
         return response['neighbors'], response['distances']
 
+    def get_topic_data(self):
+        '''
+        Returns metadata about a maps pre-computed topics
+
+        Returns:
+            A dictionary of metadata for each topic in the model
+        '''
+        response = requests.get(
+            self.project.atlas_api_path + "/v1/project/{}/index/projection/{}".format(self.project.meta['id'], self.projection_id),
+            headers=self.project.header,
+        )
+        topics = json.loads(response.text)['topic_models'][0]['features']
+        topic_data = [e['properties'] for e in topics]
+        return topic_data
+
+
+    def vector_search_topics(self, queries: np.array, k: int=32, depth: int=3):
+        '''
+        Returns the topics best associated with each vector query
+
+        Args:
+            atlas_index_id: the atlas index to use for the search
+            queries: a 2d numpy array where each row corresponds to a query vetor
+            k: (Defaul 32) the number of neighbors to use when estimating the posterior
+            depth: (Default 3) the topic depth at which you want to search
+
+        Returns:
+            A dict of {topic: posterior probability} for each query
+        '''
+
+        if queries.ndim != 2:
+            raise ValueError('Expected a 2 dimensional array. If you have a single query, we expect an array of shape (1, d).')
+
+        bytesio = io.BytesIO()
+        np.save(bytesio, queries)
+
+        status = 0
+        retries = 0
+        while status != 200 and retries < 10:
+            response = requests.post(
+                self.project.atlas_api_path + "/v1/project/data/get/embedding/topic",
+                headers=self.project.header,
+                json={'atlas_index_id': self.atlas_index_id,
+                      'queries': base64.b64encode(bytesio.getvalue()).decode('utf-8'),
+                      'k': k,
+                      'depth': depth},
+            )
+            status = response.status_code
+            retries += 1
+
+        if retries == 10:
+            print(response.text)
+            raise AssertionError('Could not get response from server')
+
+        return response.json()
+
 
     def _get_atoms(self, ids: List[str]) -> List[Dict]:
         '''
@@ -787,7 +843,6 @@ class AtlasProject(AtlasClass):
             self.meta = self._get_project_by_id(project_id)
             return
 
-
         results = self._get_existing_project_by_name(project_name=name, organization_name=organization_name)
         organization_name = results['organization_name']
 
@@ -809,8 +864,7 @@ class AtlasProject(AtlasClass):
                     f"Loading existing project `{name}` from organization `{organization_name}`."
                 )
 
-
-
+        needs_meta_refresh = False
         if project_id is None: #if there is no existing project, make a new one.
 
             if unique_id_field is None:
@@ -827,8 +881,12 @@ class AtlasProject(AtlasClass):
                 organization_name=organization_name,
                 is_public=is_public
             )
+            needs_meta_refresh = True
 
         self.meta = self._get_project_by_id(project_id=project_id)
+        if needs_meta_refresh:
+            self._latest_project_state()
+
 
     def delete(self):
         '''
@@ -897,8 +955,10 @@ class AtlasProject(AtlasClass):
         )
         if response.status_code != 201:
             raise Exception(f"Failed to create project: {response.json()}")
+        
         return response.json()['project_id']
 
+
     def _latest_project_state(self):
         '''
         Refreshes the projects state. Try to call this sparingly but use it when you need it.
